@@ -11,6 +11,9 @@ from Products.Archetypes.public import BooleanField, StringField
 from xhostplus.social import socialMessageFactory as _
 from xhostplus.social.interfaces import IProductLayer
 
+ToggleSocialButtonsPermission = 'xhostplus.social: Toggle social-buttons option'
+EditTwitterHashtagsPermission = 'xhostplus.social: Edit Twitter hashtags'
+
 class SocialBooleanField(ExtensionField, BooleanField):
     """Toggle button for enabling social buttons."""
 
@@ -35,6 +38,7 @@ class BaseExtender(object):
             ),
             required=False,
             searchable=False,
+            write_permission=ToggleSocialButtonsPermission,
         ),
 
         TwitterHashtagsField("twitterHashtags",
@@ -49,6 +53,7 @@ class BaseExtender(object):
             ),
             required=False,
             searchable=False,
+            write_permission=EditTwitterHashtagsPermission,
         ),
     ]
 
